import sys, fcntl, os
import logging

from django.core.management.base import BaseCommand

from atp.models import Groups, Vo, ServiceTypeFlavour, GroupType

import Poem_sync.django_logging
from Poem_sync.poem_sync.models import *
from Poem_sync.poem_sync.synchronize import PoemSynchronizer

logger = logging.getLogger('POEM')


class Command(BaseCommand):
    args = ''
    help = 'Synchronize this POEM_SYNC to all the registered POEMs'
    
    def __lockFile(self, lockfile):
        fd = os.open(lockfile, os.O_CREAT | os.O_TRUNC | os.O_WRONLY)
        try:
            # Request exclusive (EX) non-blocking (NB) advisory lock.
            fcntl.flock(fd, fcntl.LOCK_EX | fcntl.LOCK_NB)
        except IOError:
            return False
        return True
    
    def handle(self, *args, **options):
        logger.info("Running synchronizer for POEM sync")
        if not self.__lockFile('/tmp/poem_sync_flock'):
            logger.warning("Unable to acquire lock, another POEMSync instance might be running.")
            sys.exit(2)
        
        if not (Vo.objects.all() and ServiceTypeFlavour.objects.all()):
            logger.warning("Unable to synchronize due to empty ATP tables (ATPsync failure ?).")
            sys.exit(2)    
            
        if not Namespace.objects.filter(isdeleted = 'N'):
            logger.warning("There are no registered namespaces, please configure at least one.")
            sys.exit(2)
        
        peerlist = Namespace.objects.filter(isdeleted = 'N')
        logger.info("There are %s registered namespaces", (peerlist.count()))
        sync_ob = PoemSynchronizer()
        for peer in peerlist :
            logger.info("Starting synchronisation of %s namespace ", (peer))
            sync_ob.sync_namespace(peer)
            logger.info("Completed synchronisation of %s namespace ", (peer))
            
        # Unlink deleted namespaces, profiles, metric instances
        del_ns = Namespace.objects.filter(isdeleted = 'Y')
        if del_ns:
            logger.info("There are %s unregistered namespaces", (del_ns.count()))
            map(sync_ob.unlink_namespace, del_ns)
            
        logger.info("Synchroniser ends of POEM sync ")
        if Profile.objects.count() == 0:
            logger.error("There are no profiles after synchronization, this will not work. Please check your configuration.")
            sys.exit(2)
        if sync_ob.get_error_stat() :
            sys.exit(2)
        if sync_ob.get_warn_stat() :
            sys.exit(1)
        sys.exit(0)

        
        
