from django.db import models

from atp.models import Groups, Vo, ServiceTypeFlavour, GroupType
 
# Create your models here.    
YESNO_CHOICE = ((u'Y',u'Yes'), (u'N', u'No'),)

class MetricMapping(models.Model):
    new_metric = models.CharField(max_length=200)
    old_metric = models.CharField(max_length=200)
    
    class Meta:
        unique_together = ('new_metric', 'old_metric')
    
    def __unicode__(self):
        return self.old_metric + "-->" + self.new_metric

class Extension(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=100, blank=True, null=True)
    
    class Meta:
        ordering = ['name']
   
    def __unicode__(self):
        return self.name
    
class Expression(Extension):
    expr = models.CharField(max_length=255)
    expr_type = models.CharField(max_length=255)
    
    class Meta:
        ordering = ['expr', 'expr_type']
        
    def __unicode__(self):
        return self.name  

class Fqan(models.Model):
    fqan = models.CharField(unique=True, max_length=200)
    isdeleted = models.CharField(max_length=1,choices= YESNO_CHOICE, default='N')

    class Meta:
        ordering = ['fqan']
    
    def __unicode__(self):
        return self.fqan

class Metric(models.Model):
    name = models.CharField(unique=True, max_length=200)
    isdeleted = models.CharField(max_length=1,choices= YESNO_CHOICE, default='N')
    
    class Meta:
        ordering = ['name']
    def __unicode__(self):
        return self.name

class MetricInstance(models.Model):
    metric = models.ForeignKey(Metric)
    atp_service_type_flavour = models.ForeignKey(ServiceTypeFlavour)
    fqan = models.ForeignKey(Fqan, null=True, blank=True)
    atp_vo = models.ForeignKey(Vo)

    class Meta:
        ordering = ['metric', 'atp_service_type_flavour', 'atp_vo', 'fqan']             
        unique_together = ('metric', 'atp_service_type_flavour', 'atp_vo', 'fqan')

    def __unicode__(self):
        return self.atp_service_type_flavour.flavourname + "--" + self.metric.name + "--" + self.atp_vo

class Namespace(models.Model):
    name = models.CharField(unique=True, max_length=200)
    api_url = models.CharField(unique=True, max_length=200)
    isdeleted = models.CharField(max_length=1,choices= YESNO_CHOICE, default='N')
    
    class Meta:
        ordering = ['name', 'api_url']      
    def __unicode__(self):
        return self.name
      
class Profile(models.Model):
    name = models.CharField(max_length=128, null=False)
    tags = models.CharField(max_length=2000, blank=True, null=True)
    namespace = models.ForeignKey(Namespace)
    version = models.CharField(max_length=10, null=False, default='1.0')
    metricinstances = models.ManyToManyField(MetricInstance, through='P_M_Instances', related_name='profiles')
    extensions = models.ManyToManyField(Extension, null=True, blank=True)
    atp_groups = models.ManyToManyField(Groups)
    atp_vo = models.ForeignKey(Vo)
    valid_from = models.DateTimeField(auto_now_add=True, blank=True, null=True)
    valid_to = models.DateTimeField(blank=True, null=True)
    owner = models.CharField(max_length=255, blank=True, null=True)
    isdeleted = models.CharField(max_length=1,choices= YESNO_CHOICE, default='N')
    description = models.CharField(max_length=1024, blank=True, null=True)

    class Meta:
        ordering = ['namespace', 'name', 'version']
        unique_together = ('name', 'namespace', 'version')

    def __unicode__(self):
        return self.name

class P_M_Instances(models.Model):
    profile = models.ForeignKey(Profile)
    metricinstance = models.ForeignKey(MetricInstance)

    class Meta:
        ordering = ['profile', 'metricinstance']
        unique_together = ('profile', 'metricinstance')
    def __unicode__(self):
        return self.profile + "--" + self.metricinstance
 
