from django.test import Client, TestCase

from atp.models import  *
from Poem_sync.poem_sync.models import *
from Poem_sync.poem_sync.synchronize import *

class PoemSyncTest(TestCase):
    fixtures = ['namespace', 'extension', 'expression', 'fqan', 'metric', 'vo', 'service_type', 
                'service_type_flavour', 'metricinstance',  'profile', 'p_m_instances', 'metricmapping']
    
    def setUp(self):
        peer = Namespace.objects.filter(isdeleted = 'N')[0]
        self.syncOb = PoemSynchronizer()
        self.syncOb.set_namespace(peer)
        #syncOb.setBaseURL('file:///root/workspace/poem/poem_sync/Poem_sync/poem_sync/fixtures/api/0.1/)
    
    def testNamespace (self):
        nm = list(Namespace.objects.all())
        self.failUnlessEqual(len(nm), 1, "Namespace count equals 1")
    
    def __testSyncAObject(self, methodname, ob, check, equal = True):
        a = methodname(ob)
        if equal :
            self.failIfEqual(a, check, 'Unable to insert Object with' )
        else :
            self.failUnlessEqual(a, check, 'Unable to insert Object with' )
    
    def __testSyncAList(self, classname, methodname, oblist, numexpected, returnct, equal = True):
        ininum = classname.objects.count()
        x = len(self.syncOb.sync_object_list(oblist, methodname))
        finnum = classname.objects.count()
        num = finnum - ininum
        if equal :
            self.assertEqual(num, numexpected, 'Unable to insert the expected number of Objects got %s expected %s' % (num, numexpected))
            self.assertEqual(x, returnct, 'List does not have expected number of Objects got %s expected %s' % (x, returnct))
        else :
            self.assertNotEqual(num, numexpected, 'Unable to insert the expected number of Objects got %s expected %s' % (num, numexpected))
            
    def __testSyncAObjectEx(self, methodname, ob, check):
        self.assertRaises(SyncException, methodname, ob)
    
    def testSyncMetric(self):
        # Test metric insertion and failure
        mn = self.syncOb.sync_metric
        self.__testSyncAObject(mn, 'org.SAM.testMateric', None)
        self.__testSyncAObject(mn, '', None, False)
#        self.__testSyncAObject(mn, None, None, False)
        
    def testSyncFqan(self):
        # Test fqan insertion and failure
        mn = self.syncOb.sync_fqan
        self.__testSyncAObject(mn, '/lcgadmin', None)
        self.__testSyncAObject(mn, '', None, False)
        self.__testSyncAObject(mn, None, None, False)
    
    def testSyncServicetypeFlavour(self):
        # Test Service Type Flavour insertion and failure
        mn = self.syncOb.sync_service_type_flavour
        self.__testSyncAObject(mn, 'CE', None)
        self.__testSyncAObjectEx(mn, '', None)
        self.__testSyncAObjectEx(mn, 'XXXXXXXXXX', None)

    def testSyncMetricInstance(self):
        mn = self.syncOb.sync_metricinstance
        self.__testSyncAObject(mn, {"metric": "org.SAM.testMetric", "fqan": "/lcgadmin", "atp_service_type_flavour" : "CE", "atp_vo": "ops"}, None)
        self.__testSyncAObject(mn, {"metric": "org.SAM.testMetric", "fqan": "", "atp_service_type_flavour" : "CE", "atp_vo": "ops"}, None)
        self.__testSyncAObject(mn, {"metric": "org.SAM.testMetric", "fqan": None, "atp_service_type_flavour" : "CE", "atp_vo": "ops"}, None)
        self.__testSyncAObjectEx(mn, {"metric": "org.SAM.testMetric", "fqan": "/lcgadmin", "atp_service_type_flavour" : "CE1", "atp_vo": "ops"}, None)
        a = mn({"metric": "org.SAM.testMetric", "fqan": "", "atp_service_type_flavour" : "CE", "atp_vo": "ops"})
        self.assertEqual(a.fqan, None)
                       
    def testSyncVo(self):
        # Test Vo insertion and failure
        mn = self.syncOb.sync_vo
        self.__testSyncAObject(mn, 'Atlas', None)
        self.__testSyncAObjectEx(mn, '', None)
        self.__testSyncAObjectEx(mn, 'XXXXXXXXXX', None)
        
#    def testSyncAGroups(self):
#        # Test Groups insertion and failure
#        mn = self.syncOb.sync_groups
#        self.__testSyncAObject(mn, {'atp_grouptype' :'Site', 'atp_groupname': 'INFN-CNAF'}, None)
#        self.__testSyncAObjectEx(mn, {'atp_grouptype' :'Site1', 'atp_groupname': 'CERN'}, None)
#        self.__testSyncAObjectEx(mn, {'atp_grouptype' :'Atlas_Site', 'atp_groupname': 'CERN1111'}, None)
#        #self.__testSyncAObjectEx(mn, None, None)
    
    def testSyncAExpression(self):
        # Test Expression insertion and failure
        mn = self.syncOb.sync_expression
        self.__testSyncAObject(mn, {"extension_ptr":{"name": "GRIDVIEW"}, "name": "GRIDVIEW", "expr": "OR", "expr_type": "ACE_STF"}, None)
        self.__testSyncAObject(mn, {"extension_ptr":{"name": "GRIDVIEW_00"}, "name": "GRIDVIEW", "expr": "", "expr_type": "ACE_STF"}, None, False)
        
    def testSyncMetricInstanceList(self):
        mn = self.syncOb.sync_metricinstance
        classname = MetricInstance
        # Three Distinct Valid MetricInstances in this list
        # One is Duplicate and one is invalid
        milist = [{"metric": "org.SAM.testMetric", "fqan": "/lcgadmin", "atp_service_type_flavour" : "CE", "atp_vo": "ops"},
                  {"metric": "org.SAM.testMetric", "fqan": "", "atp_service_type_flavour" : "CE", "atp_vo": "ops"},
                  {"metric": "org.SAM.testMetric", "fqan": None, "atp_service_type_flavour" : "CE", "atp_vo": "ops"},
                  {"metric": "org.SAM.testMetric", "fqan": "/lcgadmin", "atp_service_type_flavour" : "CE1", "atp_vo": "ops"},
                  {"metric": "org.SAM.testMetric2", "fqan": "", "atp_service_type_flavour" : "CE", "atp_vo": "ops"}
                 ]
        # List will add three records but list will contain 4 objects since one is duplicate
        self.__testSyncAList(classname, mn, milist, 3, 4)
    
#    def testSyncGroupsList(self):
#        mn = self.syncOb.sync_groups
#        classname = Groups
#        # Three Distinct Valid MetricInstances in this list
#        # One is Duplicate and one is invalid
#        grlist = [{'atp_grouptype' :'Site', 'atp_groupname': 'INFN-CNAF'}, 
#                  {'atp_grouptype' :'Site1', 'atp_groupname': 'CERN'},
#                  {'atp_grouptype' :'Atlas_Site', 'atp_groupname': 'CERN1111'}
#                  ]
#        # Can add no records to Groups Table so changect will be 0
#        #only one record is found from fixture so return list contain one object 
#        self.__testSyncAList(classname, mn, grlist, 0, 1)
        
    def testSyncExpressionList(self):
        mn = self.syncOb.sync_expression
        classname = Expression
        exlist = [{"extension_ptr":{"name": "GRIDVIEW"}, "name": "GRIDVIEW", "expr": "OR", "expr_type": "ACE_STF"},
                  {"extension_ptr":{"name": "GRIDVIEW_00"}, "name": "GRIDVIEW_00", "expr": "", "expr_type": "ACE_STF"},
                  {"extension_ptr":{"name": "ACE_EXPR3"}, "name": "ACE_EXPR3", "expr": "AND", "expr_type": "ACE_STF"}
                  ]
        # out of these 3 1 is valid 1 is invalid and one is from fixture
        self.__testSyncAList(classname, mn, exlist, 1, 2)
        
    def testSyncProfileList(self):
        pmn = self.syncOb.sync_profile
        emn = self.syncOb.sync_expression
        pclassname = Profile
        eclassname = Expression
        exlist = simplejson.JSONDecoder().decode(open('poem_sync/fixtures/api/0.1/expressions').read())
        prlist = simplejson.JSONDecoder().decode(open('poem_sync/fixtures/api/0.1/profiles').read())
        self.__testSyncAList(eclassname, emn, exlist, 1, 1)
        self.__testSyncAList(pclassname, pmn, prlist, 1, 2)
        
