"""
Helper module to read, parse ncg-metric-config and determine VO independent 
metrics. This needed for the postprocessing of service metric instances. 
"""
import os
import fnmatch

from django.utils import simplejson

CONFIG_DIR='/etc/ncg-metric-config.d'
CONFIG_FILE='/etc/ncg-metric-config.conf'

def find_vo_indep_metrics():
    """
    VO independet metric is defined as any metric missing flags.VO attribute OR 
    missing flags altogether in the ncg-metric-config.
    """
    # vo independent metric is any metric missing flags.VO attribute OR missing flags altogether
    return [ metric for metric, val in parse_configs().items() 
            if 'flags' not in val.keys() or 'VO' not in val['flags'].keys() ]

def parse_configs():
    config_dict = {}
    for config_file in find_metric_config_files():
        try:
            json_config = simplejson.JSONDecoder().decode(open(config_file).read())
            config_dict.update(json_config)
        except Exception, e:
            # we will ignore all custom configuration errors
            if config_file == CONFIG_FILE:
                raise e
            else:
                continue
        
    return config_dict

def find_metric_config_files():
    config_files = [  os.path.join(CONFIG_DIR,f) for f in os.listdir(CONFIG_DIR) 
                    if fnmatch.fnmatch(f, '*.conf') ]
    config_files.append(CONFIG_FILE)
    
    return config_files    

metric_singleton=find_vo_indep_metrics()

def get_vo_indep_metrics():
    return metric_singleton