"""
Helper module to query remote Web APIs.
"""
import httplib, urlparse

from django.utils import simplejson
from django.conf import settings

def fetch_url(uri):
    uri_obj = urlparse.urlparse(uri)
    connection = httplib.HTTPConnection(uri_obj[1])
    connection.request('GET', uri)
    response = connection.getresponse()
    return (response, response.read())

def get_services(vo):
    """
    Fetch services from ATP for a given VO. Required to generate service metric instances. 
    
    Configuration:
     * settings.ATP_URL - determines ATP endpoint
     * ATP URI called: /atp/api/search/vofeeds/json?vo=%s&ismonitored=on
    
    
    """
    if settings.POEM_USE_ATP_SERVICEMAP:
        (response, content) = fetch_url(settings.ATP_URL+'/atp/api/search/servicemap/json?vo=%s&ismonitored=on' % vo)
    else:
        (response, content) = fetch_url(settings.ATP_URL+'/atp/api/search/vofeeds/json?vo=%s&ismonitored=on' % vo)
    
    if response.status == 200 and content:
        json_feed = simplejson.JSONDecoder().decode(content)
        if settings.POEM_USE_ATP_SERVICEMAP:
            srv_flv = set([ (x['id'], x['hostname'], x['flavour']['id'], x['flavour']['flavourname']) for x in json_feed ] )
        else:
            srv_flv = set([ (int(x['service_id']), x['hostname'], int(x['service_flavour_id']), x['service_flavour']) for x in json_feed ] )
        return (True, srv_flv)
    else:
        return (False, None)
