# Django settings for poem_web project.
from os import path as os_path
from ConfigParser import RawConfigParser, NoSectionError

from django.core.exceptions import ImproperlyConfigured

PROJECT_NAME = 'Poem_sync'
APP_PATH = os_path.abspath(os_path.split(__file__)[0])
PROJECT_PATH = os_path.abspath(os_path.join(APP_PATH, '..'))
CONFIG_FILE = '/etc/poem/poem_sync.ini'
DEFAULT_API = '/poem/api/0.2/json/'

config = RawConfigParser()
if not config.read([CONFIG_FILE]):
    raise ImproperlyConfigured('Unable to parse config file %s' % CONFIG_FILE)

try:
    # General
    ADMIN_NAME = config.get('general','ADMIN_NAME')
    #ADMIN_EMAIL = config.get('general','ADMIN_EMAIL')
    # Database
    # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
    DATABASES = {
        'default': {
            'NAME': config.get('database', 'DATABASE_NAME'),
            'ENGINE': config.get('database', 'DATABASE_ENGINE'),
            'USER': config.get('database', 'DATABASE_USER'),
            'PASSWORD': config.get('database', 'DATABASE_PASSWORD'),
            'HOST': config.get('database', 'DATABASE_HOST'),
            'PORT': config.get('database', 'DATABASE_PORT')
        }
    }   
    # Others
    # Make these unique, and don't share it with anybody.
    LOG_CONFIG = config.get('log', 'LOG_CONFIG')
    SECRET_KEY = config.get('others','SECRET_KEY')
    DEBUG = bool(config.get('others','DEBUG') == 'True')
    TIME_ZONE = config.get('others', 'TIME_ZONE')
    NS_URLS = config.get('others', 'POEM_SYNC_NS_URLS')
    NS_RESTRICT = config.get('others', 'POEM_SYNC_NS_RESTRICT')
    ATP_URL = config.get('others', 'ATP_URL')
    URLOPEN_TIMEOUT = config.get('others', 'URLOPEN_TIMEOUT')
    POEM_USE_ATP_SERVICEMAP=bool(config.get('others', 'POEM_USE_ATP_SERVICEMAP') == 'True')
    POEM_NAGIOS_PROFILES = config.get('others', 'POEM_NAGIOS_PROFILES')
    #selective_profile_enabled = int(config.get('selective_profile_list', 'enabled'))
    #selective_profile_file = config.get('selective_profile_list', 'LIST_FILE') 
except NoSectionError, e:
    raise ImproperlyConfigured(e)

if DEBUG:
    PISTON_DISPLAY_ERRORS = True
else:
    PISTON_DISPLAY_ERRORS = False

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
}

TEMPLATE_DEBUG = DEBUG
#ADMINS = (
    #(ADMIN_NAME, ADMIN_EMAIL),
#)
#MANAGERS = ADMINS

# Specify your custom test runner to use
#TEST_RUNNER = 'poem_web.base.tests.test_coverage.run_tests'
 
# List of modules to enable for code coverage
#COVERAGE_MODULES = ['poem_web.api', 'poem_web.base']

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
# If running in a Windows environment this must be set to the same as your
# system time zone.
#TIME_ZONE = 'America/Chicago'
#TIME_ZONE = 'UTC'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en-us'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale
USE_L10N = True

# Absolute path to the directory that holds media.
# Example: "/home/media/media.lawrence.com/"
if DEBUG:
    MEDIA_ROOT = os_path.join(APP_PATH, '/media')
else:
    MEDIA_ROOT = ''

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash if there is a path component (optional in other cases).
# Examples: "http://media.lawrence.com", "http://example.com/media/"
MEDIA_URL = ''

# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
# trailing slash.
# Examples: "http://foo.com/media/", "/media/".
ADMIN_MEDIA_PREFIX = '/media/'

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'gjrm%pqd!)3l^)x%5)nb1r%x6_2c1lo@j#)1*sh9hwwzfji8dw'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
#     'django.template.loaders.eggs.Loader',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    #'django.contrib.sessions.middleware.SessionMiddleware',
    #'django.middleware.csrf.CsrfViewMiddleware',
    #'django.contrib.auth.middleware.AuthenticationMiddleware',
    #'django.contrib.messages.middleware.MessageMiddleware',
)

ROOT_URLCONF = 'Poem_sync.urls'

TEMPLATE_DIRS = (
    os_path.join(os_path.dirname(__file__), 'templates').replace('\\','/'),
)

INSTALLED_APPS = (
    #'django.contrib.auth',
#    'django.contrib.contenttypes',
#    'django.contrib.databrowse',
    #'django.contrib.sessions',
    #'django.contrib.sites',
    #'django.contrib.messages',
    #'south',
    'Poem_sync.poem_sync',
    'Poem_sync.poem_sync_api',
    'atp'
)
