BEGIN;
CREATE TABLE `poem_sync_extension` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(100)
)
;
CREATE TABLE `poem_sync_expression` (
    `extension_ptr_id` integer NOT NULL PRIMARY KEY,
    `expr` varchar(255) NOT NULL,
    `expr_type` varchar(255) NOT NULL
)
;
ALTER TABLE `poem_sync_expression` ADD CONSTRAINT `extension_ptr_id_refs_id_ac5380cd` FOREIGN KEY (`extension_ptr_id`) REFERENCES `poem_sync_extension` (`id`);
CREATE TABLE `poem_sync_fqan` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `fqan` varchar(200) NOT NULL UNIQUE,
    `isdeleted` varchar(1) NOT NULL
)
;
CREATE TABLE `poem_sync_metric` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(200) NOT NULL UNIQUE,
    `isdeleted` varchar(1) NOT NULL
)
;
CREATE TABLE `poem_sync_metricinstance` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `metric_id` integer NOT NULL,
    `atp_service_type_flavour_id` integer NOT NULL,
    `fqan_id` integer,
    UNIQUE (`metric_id`, `atp_service_type_flavour_id`, `fqan_id`)
)
;
ALTER TABLE `poem_sync_metricinstance` ADD CONSTRAINT `fqan_id_refs_id_ecd9bb7a` FOREIGN KEY (`fqan_id`) REFERENCES `poem_sync_fqan` (`id`);
ALTER TABLE `poem_sync_metricinstance` ADD CONSTRAINT `metric_id_refs_id_71d13a46` FOREIGN KEY (`metric_id`) REFERENCES `poem_sync_metric` (`id`);
ALTER TABLE `poem_sync_metricinstance` ADD CONSTRAINT `atp_service_type_flavour_id_refs_id_8963ff94` FOREIGN KEY (`atp_service_type_flavour_id`) REFERENCES `service_type_flavour` (`id`);
CREATE TABLE `poem_sync_namespace` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(200) NOT NULL UNIQUE,
    `api_url` varchar(200) NOT NULL UNIQUE,
    `isdeleted` varchar(1) NOT NULL
)
;
CREATE TABLE `poem_sync_profile_extensions` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `extension_id` integer NOT NULL,
    UNIQUE (`profile_id`, `extension_id`)
)
;
ALTER TABLE `poem_sync_profile_extensions` ADD CONSTRAINT `extension_id_refs_id_b9b52091` FOREIGN KEY (`extension_id`) REFERENCES `poem_sync_extension` (`id`);
CREATE TABLE `poem_sync_profile_atp_groups` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `groups_id` integer NOT NULL,
    UNIQUE (`profile_id`, `groups_id`)
)
;
ALTER TABLE `poem_sync_profile_atp_groups` ADD CONSTRAINT `groups_id_refs_id_fd14eadf` FOREIGN KEY (`groups_id`) REFERENCES `groups` (`id`);
CREATE TABLE `poem_sync_profile_metricinstances` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `metricinstance_id` integer NOT NULL,
    UNIQUE (`profile_id`, `metricinstance_id`)
)
;
ALTER TABLE `poem_sync_profile_metricinstances` ADD CONSTRAINT `metricinstance_id_refs_id_c1354cfd` FOREIGN KEY (`metricinstance_id`) REFERENCES `poem_sync_metricinstance` (`id`);
CREATE TABLE `poem_sync_profile` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(128) NOT NULL,
    `namespace_id` integer NOT NULL,
    `version` varchar(10) NOT NULL,
    `atp_vo_id` integer NOT NULL,
    `valid_from` datetime,
    `valid_to` datetime,
    `owner` varchar(128),
    `isdeleted` varchar(1) NOT NULL,
    UNIQUE (`name`, `namespace_id`, `version`)
)
;
ALTER TABLE `poem_sync_profile` ADD CONSTRAINT `atp_vo_id_refs_id_6b752778` FOREIGN KEY (`atp_vo_id`) REFERENCES `vo` (`id`);
ALTER TABLE `poem_sync_profile` ADD CONSTRAINT `namespace_id_refs_id_3bb248a9` FOREIGN KEY (`namespace_id`) REFERENCES `poem_sync_namespace` (`id`);
ALTER TABLE `poem_sync_profile_extensions` ADD CONSTRAINT `profile_id_refs_id_b85d58a1` FOREIGN KEY (`profile_id`) REFERENCES `poem_sync_profile` (`id`);
ALTER TABLE `poem_sync_profile_atp_groups` ADD CONSTRAINT `profile_id_refs_id_12a208a5` FOREIGN KEY (`profile_id`) REFERENCES `poem_sync_profile` (`id`);
ALTER TABLE `poem_sync_profile_metricinstances` ADD CONSTRAINT `profile_id_refs_id_539628b2` FOREIGN KEY (`profile_id`) REFERENCES `poem_sync_profile` (`id`);
CREATE INDEX `poem_sync_metricinstance_85fa1a12` ON `poem_sync_metricinstance` (`metric_id`);
CREATE INDEX `poem_sync_metricinstance_c1d19eba` ON `poem_sync_metricinstance` (`atp_service_type_flavour_id`);
CREATE INDEX `poem_sync_metricinstance_f55b9a1e` ON `poem_sync_metricinstance` (`fqan_id`);
CREATE INDEX `poem_sync_profile_214c2854` ON `poem_sync_profile` (`namespace_id`);
CREATE INDEX `poem_sync_profile_4ea7f003` ON `poem_sync_profile` (`atp_vo_id`);
COMMIT;
CREATE TABLE IF NOT EXISTS schema_details (
     id INT AUTO_INCREMENT NOT NULL,
     ver VARCHAR(20) NOT NULL,
     db_name VARCHAR(200),
     creation_date DATETIME NOT NULL,
     remarks VARCHAR(1000) BINARY NULL,
     PRIMARY KEY (id),
     CONSTRAINT `uk_schema_details`
          UNIQUE KEY (`ver`, `db_name`)
) ENGINE=INNODB;

-- Schema Version

INSERT INTO schema_details(ver,creation_date,remarks,db_name) VALUES('1.0', NOW(), 'Version 1.0 of the schema', 'poem_sync');
COMMIT;

