BEGIN;
CREATE TABLE `poem_sync_metricmapping` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `new_metric` varchar(200) NOT NULL,
    `old_metric` varchar(200) NOT NULL,
    UNIQUE (`new_metric`, `old_metric`)
)
;
CREATE TABLE `poem_sync_extension` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(100)
)
;
CREATE TABLE `poem_sync_expression` (
    `extension_ptr_id` integer NOT NULL PRIMARY KEY,
    `expr` varchar(255) NOT NULL,
    `expr_type` varchar(255) NOT NULL
)
;
ALTER TABLE `poem_sync_expression` ADD CONSTRAINT `extension_ptr_id_refs_id_ac5380cd` FOREIGN KEY (`extension_ptr_id`) REFERENCES `poem_sync_extension` (`id`);
CREATE TABLE `poem_sync_fqan` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `fqan` varchar(200) NOT NULL UNIQUE,
    `isdeleted` varchar(1) NOT NULL
)
;
CREATE TABLE `poem_sync_metric` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(200) NOT NULL UNIQUE,
    `isdeleted` varchar(1) NOT NULL
)
;
CREATE TABLE `poem_sync_metricinstance` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `metric_id` integer NOT NULL,
    `atp_service_type_flavour_id` integer NOT NULL,
    `fqan_id` integer,
    `atp_vo_id` integer NOT NULL,
    UNIQUE (`metric_id`, `atp_service_type_flavour_id`, `atp_vo_id`, `fqan_id`)
)
;
ALTER TABLE `poem_sync_metricinstance` ADD CONSTRAINT `atp_vo_id_refs_id_aebfee19` FOREIGN KEY (`atp_vo_id`) REFERENCES `vo` (`id`);
ALTER TABLE `poem_sync_metricinstance` ADD CONSTRAINT `fqan_id_refs_id_ecd9bb7a` FOREIGN KEY (`fqan_id`) REFERENCES `poem_sync_fqan` (`id`);
ALTER TABLE `poem_sync_metricinstance` ADD CONSTRAINT `atp_service_type_flavour_id_refs_id_8963ff94` FOREIGN KEY (`atp_service_type_flavour_id`) REFERENCES `service_type_flavour` (`id`);
ALTER TABLE `poem_sync_metricinstance` ADD CONSTRAINT `metric_id_refs_id_71d13a46` FOREIGN KEY (`metric_id`) REFERENCES `poem_sync_metric` (`id`);
CREATE TABLE `poem_sync_namespace` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(200) NOT NULL UNIQUE,
    `api_url` varchar(200) NOT NULL UNIQUE,
    `isdeleted` varchar(1) NOT NULL
)
;
CREATE TABLE `poem_sync_profile` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `name` varchar(128) NOT NULL,
    `tags` varchar(2000),
    `namespace_id` integer NOT NULL,
    `version` varchar(10) NOT NULL,
    `atp_vo_id` integer NOT NULL,
    `valid_from` datetime,
    `valid_to` datetime,
    `owner` varchar(255),
    `isdeleted` varchar(1) NOT NULL,
    `description` varchar(1024),
    UNIQUE (`name`, `namespace_id`, `version`)
)
;
ALTER TABLE `poem_sync_profile` ADD CONSTRAINT `namespace_id_refs_id_3bb248a9` FOREIGN KEY (`namespace_id`) REFERENCES `poem_sync_namespace` (`id`);
CREATE TABLE `poem_sync_p_m_instances` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `metricinstance_id` integer NOT NULL,
    UNIQUE (`profile_id`, `metricinstance_id`)
)
;
ALTER TABLE `poem_sync_p_m_instances` ADD CONSTRAINT `profile_id_refs_id_944bae5f` FOREIGN KEY (`profile_id`) REFERENCES `poem_sync_profile` (`id`);
ALTER TABLE `poem_sync_p_m_instances` ADD CONSTRAINT `metricinstance_id_refs_id_628f05de` FOREIGN KEY (`metricinstance_id`) REFERENCES `poem_sync_metricinstance` (`id`);
CREATE TABLE `poem_sync_profile_extensions` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `extension_id` integer NOT NULL,
    UNIQUE (`profile_id`, `extension_id`)
)
;
ALTER TABLE `poem_sync_profile_extensions` ADD CONSTRAINT `profile_id_refs_id_b85d58a1` FOREIGN KEY (`profile_id`) REFERENCES `poem_sync_profile` (`id`);
ALTER TABLE `poem_sync_profile_extensions` ADD CONSTRAINT `extension_id_refs_id_b9b52091` FOREIGN KEY (`extension_id`) REFERENCES `poem_sync_extension` (`id`);
CREATE TABLE `poem_sync_profile_atp_groups` (
    `id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY,
    `profile_id` integer NOT NULL,
    `groups_id` integer NOT NULL,
    UNIQUE (`profile_id`, `groups_id`)
)
;
ALTER TABLE `poem_sync_profile_atp_groups` ADD CONSTRAINT `profile_id_refs_id_12a208a5` FOREIGN KEY (`profile_id`) REFERENCES `poem_sync_profile` (`id`);
ALTER TABLE `poem_sync_profile_atp_groups` ADD CONSTRAINT `groups_id_refs_id_fd14eadf` FOREIGN KEY (`groups_id`) REFERENCES `groups` (`id`);
ALTER TABLE `poem_sync_profile` ADD CONSTRAINT `atp_vo_id_refs_id_6b752778` FOREIGN KEY (`atp_vo_id`) REFERENCES `vo` (`id`);

CREATE INDEX `poem_sync_metricinstance_metric_id` ON `poem_sync_metricinstance` (`metric_id`);
CREATE INDEX `poem_sync_metricinstance_atp_service_type_flavour_id` ON `poem_sync_metricinstance` (`atp_service_type_flavour_id`);
CREATE INDEX `poem_sync_metricinstance_fqan_id` ON `poem_sync_metricinstance` (`fqan_id`);
CREATE INDEX `poem_sync_metricinstance_atp_vo_id` ON `poem_sync_metricinstance` (`atp_vo_id`);
CREATE INDEX `poem_sync_profile_namespace_id` ON `poem_sync_profile` (`namespace_id`);
CREATE INDEX `poem_sync_profile_atp_vo_id` ON `poem_sync_profile` (`atp_vo_id`);
CREATE INDEX `poem_sync_p_m_instances_profile_id` ON `poem_sync_p_m_instances` (`profile_id`);
CREATE INDEX `poem_sync_p_m_instances_metricinstance_id` ON `poem_sync_p_m_instances` (`metricinstance_id`);

ALTER TABLE `poem_sync_metricmapping` ENGINE=INNODB;
ALTER TABLE `poem_sync_extension` ENGINE=INNODB;
ALTER TABLE `poem_sync_expression` ENGINE=INNODB;
ALTER TABLE `poem_sync_fqan` ENGINE=INNODB;
ALTER TABLE `poem_sync_metric` ENGINE=INNODB;
ALTER TABLE `poem_sync_metricinstance` ENGINE=INNODB;
ALTER TABLE `poem_sync_namespace` ENGINE=INNODB;
ALTER TABLE `poem_sync_profile_extensions` ENGINE=INNODB;
ALTER TABLE `poem_sync_profile_atp_groups` ENGINE=INNODB;
ALTER TABLE `poem_sync_p_m_instances` ENGINE=INNODB;
ALTER TABLE `poem_sync_profile` ENGINE=INNODB;


INSERT INTO `poem_sync_metricmapping` (`new_metric`, `old_metric`) VALUES 
			('emi.cream.CREAMCE-DirectJobSubmit', 'org.sam.CREAMCE-DirectJobSubmit'),
			('emi.cream.CREAMCE-JobSubmit','org.sam.CREAMCE-JobSubmit'),
			('emi.wn.WN-Bi','org.sam.WN-Bi'),
			('emi.wn.WN-Csh','org.sam.WN-Csh'),
			('emi.wn.WN-SoftVer','org.sam.WN-SoftVer'),
			('emi.wms.WMS-JobSubmit','org.sam.WMS-JobSubmit'),
			('emi.cream.glexec.CREAMCE-JobSubmit', 'org.sam.glexec.CE-JobSubmit'),
			('emi.cream.glexec.WN-gLExec','org.sam.glexec.WN-gLExec'),
			('emi.ce.CREAMCE-JobSubmit','org.sam.CE-JobSubmit'),
			('org.nordugrid.ARC-CE-ARIS','org.arc.ARC-STATUS'),
			('org.nordugrid.ARC-CE-IGTF','org.arc.CA-VERSION'),
			('org.nordugrid.ARC-CE-sw-csh','org.arc.csh'),
			('org.nordugrid.ARC-CE-sw-gcc','org.arc.gcc'),
			('org.nordugrid.ARC-CE-sw-perl','org.arc.perl'),
			('org.nordugrid.ARC-CE-sw-python','org.arc.python'),
			('org.nordugrid.ARC-CE-result','org.arc.Jobsubmit'),
			('org.nordugrid.ARC-CE-lfc','org.arc.LFC'),
			('org.nordugrid.ARC-CE-srm','org.arc.SRM');
			
-- Schema Version

INSERT INTO schema_details(ver,creation_date,remarks,db_name) VALUES('1.4', NOW(), 'Version 1.4 of the schema', 'poem_sync');

COMMIT;
