CREATE TABLE "POEM_SYNC_EXTENSION" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(100)
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_EXTENSION_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_EXTENSION_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_EXTENSION_TR"
BEFORE INSERT ON "POEM_SYNC_EXTENSION"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_EXTENSION_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_EXPRESSION" (
    "EXTENSION_PTR_ID" NUMBER(11) NOT NULL PRIMARY KEY REFERENCES "POEM_SYNC_EXTENSION" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "EXPR" NVARCHAR2(255),
    "EXPR_TYPE" NVARCHAR2(255)
)
;
CREATE TABLE "POEM_SYNC_FQAN" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "FQAN" NVARCHAR2(200) UNIQUE,
    "ISDELETED" NVARCHAR2(1)
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_FQAN_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_FQAN_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_FQAN_TR"
BEFORE INSERT ON "POEM_SYNC_FQAN"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_FQAN_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_METRIC" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(200) UNIQUE,
    "ISDELETED" NVARCHAR2(1)
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_METRIC_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_METRIC_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_METRIC_TR"
BEFORE INSERT ON "POEM_SYNC_METRIC"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_METRIC_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_METRICINSTANCE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "METRIC_ID" NUMBER(11) NOT NULL REFERENCES "POEM_SYNC_METRIC" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "ATP_SERVICE_TYPE_FLAVOUR_ID" NUMBER(11) NOT NULL REFERENCES "SERVICE_TYPE_FLAVOUR" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "FQAN_ID" NUMBER(11) REFERENCES "POEM_SYNC_FQAN" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "ATP_VO_ID" NUMBER(11) NOT NULL REFERENCES "VO" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("METRIC_ID", "ATP_SERVICE_TYPE_FLAVOUR_ID", "ATP_VO_ID", "FQAN_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_METRICINSTANCE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_METRICINSTANCE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_METRICINSTANCE_TR"
BEFORE INSERT ON "POEM_SYNC_METRICINSTANCE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_METRICINSTANCE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_NAMESPACE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(200) UNIQUE,
    "API_URL" NVARCHAR2(200) UNIQUE,
    "ISDELETED" NVARCHAR2(1)
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_NAMESPACE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_NAMESPACE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_NAMESPACE_TR"
BEFORE INSERT ON "POEM_SYNC_NAMESPACE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_NAMESPACE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_PROFILE" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "NAME" NVARCHAR2(128),
    "TAGS" NVARCHAR2(2000),
    "NAMESPACE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_SYNC_NAMESPACE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "VERSION" NVARCHAR2(10),
    "ATP_VO_ID" NUMBER(11) NOT NULL REFERENCES "VO" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "VALID_FROM" TIMESTAMP,
    "VALID_TO" TIMESTAMP,
    "OWNER" NVARCHAR2(255),
    "ISDELETED" NVARCHAR2(1),
    "DESCRIPTION" NVARCHAR2(1024),
    UNIQUE ("NAME", "NAMESPACE_ID", "VERSION")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_PROFILE_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_PROFILE_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_PROFILE_TR"
BEFORE INSERT ON "POEM_SYNC_PROFILE"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_PROFILE_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_P_M_INSTANCES" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "PROFILE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_SYNC_PROFILE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "METRICINSTANCE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_SYNC_METRICINSTANCE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("PROFILE_ID", "METRICINSTANCE_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_P_M_INSTANCES_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_P_M_INSTANCES_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_P_M_INSTANCES_TR"
BEFORE INSERT ON "POEM_SYNC_P_M_INSTANCES"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_P_M_INSTANCES_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_PROFILE_EXTENSIONS" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "PROFILE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_SYNC_PROFILE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "EXTENSION_ID" NUMBER(11) NOT NULL REFERENCES "POEM_SYNC_EXTENSION" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("PROFILE_ID", "EXTENSION_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_PROFILE_EXTEN5405_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_PROFILE_EXTEN5405_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_PROFILE_EXTEN5405_TR"
BEFORE INSERT ON "POEM_SYNC_PROFILE_EXTENSIONS"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_PROFILE_EXTEN5405_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE TABLE "POEM_SYNC_PROFILE_ATP_GROUPS" (
    "ID" NUMBER(11) NOT NULL PRIMARY KEY,
    "PROFILE_ID" NUMBER(11) NOT NULL REFERENCES "POEM_SYNC_PROFILE" ("ID") DEFERRABLE INITIALLY DEFERRED,
    "GROUPS_ID" NUMBER(11) NOT NULL REFERENCES "GROUPS" ("ID") DEFERRABLE INITIALLY DEFERRED,
    UNIQUE ("PROFILE_ID", "GROUPS_ID")
)
;

DECLARE
    i INTEGER;
BEGIN
    SELECT COUNT(*) INTO i FROM USER_CATALOG
        WHERE TABLE_NAME = 'POEM_SYNC_PROFILE_ATP_G248B_SQ' AND TABLE_TYPE = 'SEQUENCE';
    IF i = 0 THEN
        EXECUTE IMMEDIATE 'CREATE SEQUENCE "POEM_SYNC_PROFILE_ATP_G248B_SQ"';
    END IF;
END;
/

CREATE OR REPLACE TRIGGER "POEM_SYNC_PROFILE_ATP_G248B_TR"
BEFORE INSERT ON "POEM_SYNC_PROFILE_ATP_GROUPS"
FOR EACH ROW
WHEN (new."ID" IS NULL)
    BEGIN
        SELECT "POEM_SYNC_PROFILE_ATP_G248B_SQ".nextval
        INTO :new."ID" FROM dual;
    END;
/
CREATE INDEX "POEM_SYNC_METRICINSTANCE_M6DF5" ON "POEM_SYNC_METRICINSTANCE" ("METRIC_ID");
CREATE INDEX "POEM_SYNC_METRICINSTANCE_AAC21" ON "POEM_SYNC_METRICINSTANCE" ("ATP_SERVICE_TYPE_FLAVOUR_ID");
CREATE INDEX "POEM_SYNC_METRICINSTANCE_F7BB1" ON "POEM_SYNC_METRICINSTANCE" ("FQAN_ID");
CREATE INDEX "POEM_SYNC_METRICINSTANCE_A6E84" ON "POEM_SYNC_METRICINSTANCE" ("ATP_VO_ID");
CREATE INDEX "POEM_SYNC_PROFILE_NAMESPACE_ID" ON "POEM_SYNC_PROFILE" ("NAMESPACE_ID");
CREATE INDEX "POEM_SYNC_PROFILE_ATP_VO_ID" ON "POEM_SYNC_PROFILE" ("ATP_VO_ID");
CREATE INDEX "POEM_SYNC_P_M_INSTANCES_PRAB59" ON "POEM_SYNC_P_M_INSTANCES" ("PROFILE_ID");
CREATE INDEX "POEM_SYNC_P_M_INSTANCES_ME78D9" ON "POEM_SYNC_P_M_INSTANCES" ("METRICINSTANCE_ID");

INSERT INTO schema_details(ver,creation_date,remarks,db_name) VALUES('1.3', sysdate, 'Version 1.3 of the schema', 'poem_sync');
COMMIT;
